from maltego_trx.decorator_registry import TransformRegistry

registry = TransformRegistry(
        owner="ACME Corporation",
        author="John Doe <johndoe@acme.com>",
        host_url="https://transforms.acme.com",
        seed_ids=["demo"]
)

# The rest of these attributes are optional

# metadata
registry.version = "0.1"

# global settings
# from maltego_trx.template_dir.settings import api_key_setting
# registry.global_settings = [api_key_setting]

# transform suffix to indicate datasource
# registry.display_name_suffix = " [ACME]"

# reference OAuth settings
# registry.oauth_settings_id = ['github-oauth']



from enum import Enum


class OverlayPosition(Enum):
    NORTH = "N"
    SOUTH = "S"
    WEST = "W"
    NORTH_WEST = "NW"
    SOUTH_WEST = "SW"
    CENTER = "C"


class OverlayType(Enum):
    IMAGE = "image"
    COLOUR = "colour"
    TEXT = "text"



import logging
import pkgutil

from .transform import DiscoverableTransform
from .utils import name_to_path

log = logging.getLogger(__name__)
module_name = "transforms"

transform_functions = []
transform_classes = []
mapping = {}


def update_mapping():
    # Get mapping from URL path to transform
    global mapping
    for transform in transform_functions + transform_classes:
        url_path = name_to_path(transform.__name__)
        mapping[url_path] = transform


def register_transform_function(transform_function):
    # Register a transform function with the server.
    global transform_functions
    if transform_function not in transform_functions:
        transform_functions.append(transform_function)
    else:
        log.warning("Transform function already registered.")
    update_mapping()


def register_transform_classes(module):
    # Register transform classes from a given python module
    global transform_classes

    prefix = module.__name__ + "."  # transform.
    for importer, modname, ispkg in pkgutil.iter_modules(module.__path__, prefix):
        if not ispkg:
            module = __import__(modname, fromlist="dummy")
            name = module.__name__.replace(prefix, '')  # strip transform. prefix from module name

            if hasattr(module, name):  # Does the .py file have a class of the same name.
                transform_cls = getattr(module, name)
                if issubclass(transform_cls, DiscoverableTransform):  # Does the class subclass MaltegoTransform
                    transform_classes.append(transform_cls)
            else:
                log.info('Ignoring File: "%s" does not contain a class of the same name' % name)
    update_mapping()


def print_registered():
    print("Transform Functions:")
    for func in transform_functions:
        print(func.__name__)
    print("")
    print("Transform Classes:")
    for cls in transform_classes:
        print(cls.__name__)


import sys
import transforms

from maltego_trx.registry import register_transform_function, register_transform_classes
from maltego_trx.server import app, application
from maltego_trx.handler import handle_run
from maltego_trx.template_dir.extensions import registry

# register_transform_function(transform_func)
register_transform_classes(transforms)

registry.write_transforms_config()
registry.write_settings_config()

handle_run(__name__, sys.argv, app)



Alias = "maltego.Alias"
ASNumber = "maltego.AS"
BuiltwithTechnology = "maltego.BuiltWithTechnology"
BuiltWithRelationship = "maltego.BuiltWithRelationship"
CircularArea = "maltego.CircularArea"
Company = "maltego.Company"
Device = "maltego.Device"
DNS = "maltego.DNSName"
Document = "maltego.Document"
Domain = "maltego.Domain"
Email = "maltego.EmailAddress"
FlickrAffiliation = "maltego.AffiliationFlickr"
GPS = "maltego.GPS"
Hash = "maltego.Hash"
Hashtag = "maltego.Hashtag"
Image = "maltego.Image"
IPAddress = "maltego.IPv4Address"
Location = "maltego.Location"
MX = "maltego.MXRecord"
MyspaceAffiliation = "maltego.AffiliationMyspace"
Namechk = "maltego.Namechk"
Netblock = "maltego.Netblock"
NS = "maltego.NSRecord"
Organization = "maltego.Organization"
Person = "maltego.Person"
PhoneNumber = "maltego.PhoneNumber"
Phrase = "maltego.Phrase"
Port = "maltego.Port"
Sentiment = "maltego.Sentiment"
StockSymbol = "maltego.StockSymbol"
Tweet = "maltego.Twit"
TwitterAffiliation = "maltego.AffiliationTwitter"
TwitterList = "maltego.TwitterUserList"
UniqueID = "maltego.UniqueIdentifier"
URL = "maltego.URL"
Website = "maltego.Website"
WebTitle = "maltego.WebTitle"

# {entityName: {version2PropertyName: version3PropertyName,...}}
entity_property_map = {
    "maltego.Person": {"firstname": "person.firstnames", "lastname": "person.lastname"},
    "maltego.Domain": {"whois": "whois-info"},
    "maltego.IPv4Address": {"whois": "whois-info"},
    "maltego.URL": {"maltego.v2.value.property": "short-title", "theurl": "url", "fulltitle": "title"},
    "maltego.Document": {"maltego.v2.value.property": "title", "link": "url", "metainfo": "document.meta-data"},
    "maltego.Location": {"area": "location.area", "countrysc": "url", "long": "longitude", "lat": "latitude"},
    "maltego.PhoneNumber": {
        "countrycode": "phonenumber.countrycode", "citycode": "phonenumber.citycode",
        "areacode": "phonenumber.areacode", "lastnumbers": "phonenumber.lastnumbers"
    },
    "maltego.affiliation.Spock": {
        "network": "affiliation.network", "uid": "affiliation.uid", "profile_url": "affiliation.profile-url",
        "spock_websites": "spock.websites"
    },
    "maltego.affiliation": {
        "network": "affiliation.network", "uid": "affiliation.uid", "profile_url": "affiliation.profile-url"
    },
    "maltego.Service": {"banner": "banner.text", "port": "port.number"},
    "maltego.Alias": {"properties.alias": "alias"},
    "maltego.Device": {"properties.device": "device"},
    "maltego.GPS": {"properties.gps": "gps.coordinate"},
    "maltego.CircularArea": {"area": "radius"},
    "maltego.Image": {"properties.image": "description", "fullImage": "url"},
    "maltego.NominatimLocation": {"properties.nominatimlocation": "nominatimlocation"},
    "maltego.BuiltWithTechnology": {"properties.builtwithtechnology": "builtwith.technology"},
    "maltego.FacebookObject": {"properties.facebookobject": "facebook.object"}
}


def translate_legacy_property_name(entity_type, v2_property):
    """Function maps a legacy version 2 entity property name to version 3 entity property name"""
    return entity_property_map .get(entity_type, {}).get(v2_property)



from maltego_trx import VERSION
from .server import print_transforms, run_transform, get_exception_message
from .registry import mapping
from .maltego import MaltegoMsg


"""
Receive commands run inside a project folder.
"""

def handle_run(name, args, app, port=8080, ssl_context=None, debug=False):
    if name == "__main__":
        if len(args) >= 2:
            command = args[1].lower()
            if command == "runserver":
                print("\n=== Maltego Transform Server: v%s ===\n" % VERSION)
                print_transforms()
                app.run(host="0.0.0.0", port=port, debug=debug, ssl_context=ssl_context)
            elif command == "list":
                print_transforms()
            elif command == "local" and len(args) > 3:
                transform_name = args[2].lower()
                if transform_name in mapping:
                    client_msg = MaltegoMsg(LocalArgs=args[3:])
                    print(run_transform(transform_name, client_msg)[0])
                else:
                    print(get_exception_message(msg="Unable to find a transform matching '%s'." % transform_name))

        else:
            commands = ["list", "local", "runserver"]
            print("Command not recognised. Available commands are:\r\n{0}".format("\r\n".join(commands)))




import uuid;

from xml.dom import minidom

from .entities import Phrase, translate_legacy_property_name, entity_property_map
from .overlays import OverlayPosition, OverlayType
from .utils import remove_invalid_xml_chars

BOOKMARK_COLOR_NONE = "-1"
BOOKMARK_COLOR_BLUE = "0"
BOOKMARK_COLOR_GREEN = "1"
BOOKMARK_COLOR_YELLOW = "2"
BOOKMARK_COLOR_PURPLE = "3"
BOOKMARK_COLOR_RED = "4"
BOOKMARK_CLRS = {
    "none": BOOKMARK_COLOR_NONE,
    "blue": BOOKMARK_COLOR_BLUE,
    "green": BOOKMARK_COLOR_GREEN,
    "yellow": BOOKMARK_COLOR_YELLOW,
    "purple": BOOKMARK_COLOR_PURPLE,
    "red": BOOKMARK_COLOR_RED,
}

LINK_STYLE_NORMAL = "0"
LINK_STYLE_DASHED = "1"
LINK_STYLE_DOTTED = "2"
LINK_STYLE_DASHDOT = "3"
LINK_STYLES = {
    "normal": LINK_STYLE_NORMAL,
    "dashed": LINK_STYLE_DASHED,
    "dotted": LINK_STYLE_DOTTED,
    "dashdot": LINK_STYLE_DASHDOT,
}

UIM_FATAL = 'FatalError'
UIM_PARTIAL = 'PartialError'
UIM_INFORM = 'Inform'
UIM_DEBUG = 'Debug'
UIM_TYPES = {
    "fatal": UIM_FATAL,
    "partial": UIM_PARTIAL,
    "inform": UIM_INFORM,
    "debug": UIM_DEBUG,
}

ADD_FIELD_TEMPLATE = "<Field MatchingRule=\"%(matching)s\" Name=\"%(name)s\" DisplayName=\"%(display)s\"><![CDATA[%(value)s]]></Field>"
DISP_INFO_TEMPLATE = "<Label Name=\"%(name)s\" Type=\"text/html\"><![CDATA[' %(content)s ']]></Label>"
UIM_TEMPLATE = "<UIMessage MessageType=\"%(type)s\">%(text)s</UIMessage>"
OVERLAY_TEMPLATE = "<Overlay position=\"%(position)s\" propertyName=\"%(property_name)s\" type=\"%(type)s\"/>"


class MaltegoEntity(object):
    def __init__(self, type=None, value=None):
        self.entityType = type if type else Phrase
        self.value = value if value else ""

        self.weight = 100
        self.additionalFields = []
        self.displayInformation = []
        self.iconURL = ""
        self.overlays = []

    def setType(self, type=None):
        if type:
            self.entityType = type

    def setValue(self, value=None):
        if value:
            self.value = value

    def setWeight(self, weight=None):
        if weight:
            self.weight = weight

    def addDisplayInformation(self, content=None, title='Info'):
        if content:
            self.displayInformation.append([title, content])

    def addProperty(self, fieldName=None, displayName=None, matchingRule='loose', value=None):
        self.additionalFields.append([fieldName, displayName, matchingRule, value])

    def setIconURL(self, url=None):
        if url:
            self.iconURL = url

    def setLinkColor(self, color):
        self.addProperty('link#maltego.link.color', 'LinkColor', '', color)

    def setLinkStyle(self, style):
        self.addProperty('link#maltego.link.style', 'LinkStyle', '', style)

    def setLinkThickness(self, thick):
        self.addProperty('link#maltego.link.thickness', 'Thickness', '', str(thick))

    def setLinkLabel(self, label):
        self.addProperty('link#maltego.link.label', 'Label', '', label)

    def reverseLink(self):
        self.addProperty('link#maltego.link.direction', 'link#maltego.link.direction', 'loose', 'output-to-input')

    def addCustomLinkProperty(self, fieldName=None, displayName=None, value=None):
        self.addProperty('link#' + fieldName, displayName, '', value)

    def setBookmark(self, bookmark):
        self.addProperty('bookmark#', 'Bookmark', '', bookmark)

    def setNote(self, note):
        self.addProperty('notes#', 'Notes', '', note)

    def addOverlay(
            self, propertyName, position: OverlayPosition, overlayType: OverlayType
    ):
        self.overlays.append([propertyName, position.value, overlayType.value])

    def add_field_to_xml(self, additional_field):
        name, display, matching, value = additional_field
        matching = "strict" if matching.lower().strip() == "strict" else "loose"

        return ADD_FIELD_TEMPLATE % {
            "matching": matching,
            "name": name,
            "display": display,
            "value": remove_invalid_xml_chars(value),
        }

    def disp_info_to_xml(self, disp_info):
        name, content = disp_info

        return DISP_INFO_TEMPLATE % {
            "content": remove_invalid_xml_chars(content),
            "name": name,
        }

    def returnEntity(self):
        lines = []
        lines.append("<Entity Type=\"%s\">" % str(self.entityType))
        lines.append("<Value><![CDATA[%s]]></Value>" % str(self.value))
        lines.append("<Weight>%s</Weight>" % str(self.weight))
        if self.displayInformation:
            lines.append("<DisplayInformation>")
            for disp_info in self.displayInformation:
                lines.append(self.disp_info_to_xml(disp_info))
            lines.append("</DisplayInformation>")

        if self.additionalFields:
            lines.append("<AdditionalFields>")
            for additional_field in self.additionalFields:
                lines.append(self.add_field_to_xml(additional_field))
            lines.append("</AdditionalFields>")

        if self.overlays:
            lines.append("<Overlays>")
            for overlay in self.overlays:
                overlay_tag = OVERLAY_TEMPLATE % {
                    "property_name": overlay[0],
                    "position": overlay[1],
                    "type": overlay[2],
                }
                lines.append(overlay_tag)
            lines.append("</Overlays>")
        if self.iconURL:
            lines.append("<IconURL>%s</IconURL>" % self.iconURL)

        lines.append("</Entity>")
        return "".join(lines)


class MaltegoTransform(object):
    def __init__(self):
        self.entities = []
        self.exceptions = []
        self.UIMessages = []

    def addEntity(self, type=None, value=None):
        entity = MaltegoEntity(type, value)
        self.entities.append(entity)
        return entity

    def addUIMessage(self, message, messageType="Inform"):
        self.UIMessages.append([messageType, message])

    def addException(self, exceptionString):
        self.exceptions.append(exceptionString)

    def throwExceptions(self):
        lines = []
        lines.append("<MaltegoMessage>")
        lines.append("<MaltegoTransformExceptionMessage>")
        lines.append("<Exceptions>")

        for exception in self.exceptions:
            lines.append("<Exception>%s</Exception>" % remove_invalid_xml_chars(exception))

        lines.append("</Exceptions>")
        lines.append("</MaltegoTransformExceptionMessage>")
        lines.append("</MaltegoMessage>")
        return "".join(lines)

    def returnOutput(self):
        lines = []
        lines.append("<MaltegoMessage>")
        lines.append("<MaltegoTransformResponseMessage>")

        lines.append("<Entities>")
        for entity in self.entities:
            lines.append(entity.returnEntity())
        lines.append("</Entities>")

        lines.append("<UIMessages>")
        for message in self.UIMessages:
            type, message = message
            lines.append(UIM_TEMPLATE % {"text": message, "type": type})
        lines.append("</UIMessages>")

        lines.append("</MaltegoTransformResponseMessage>")
        lines.append("</MaltegoMessage>")
        return "".join(lines)


class MaltegoMsg:
    @staticmethod
    def _get_text(element):
        for child in element.childNodes:
            if child.nodeType == child.TEXT_NODE:
                return child.data

    @staticmethod
    def _get_int(element, tag_name, attr_name=None):
        try:
            element = element.getElementsByTagName(tag_name)[0]
            value = MaltegoMsg._get_text(element) if not attr_name else element.getAttribute(attr_name)
            return int(value)
        except ValueError:
            print("Error: Unable to convert XML value for '%s' to an integer." % tag_name)
            return 0

    def __init__(self, MaltegoXML="", LocalArgs=[]):
        if MaltegoXML:
            maltego_msg = minidom.parseString(MaltegoXML)
            entities = maltego_msg.getElementsByTagName("Entity")
            entity = entities[0]

            self.Value = self._get_text(entity.getElementsByTagName("Value")[0])
            self.Type = entity.attributes["Type"].value

            self.Weight = self._get_int(entity, "Weight")
            self.Slider = self._get_int(maltego_msg, "Limits", attr_name="SoftLimit")
            self.Genealogy = []
            genealogy_tag = maltego_msg.getElementsByTagName("Genealogy")
            genealogy_types = genealogy_tag[0].getElementsByTagName("Type") if genealogy_tag else []
            for genealogy_type_tag in genealogy_types:
                entity_type_name = genealogy_type_tag.getAttribute("Name")
                entity_type_old_name = genealogy_type_tag.getAttribute("OldName")
                entity_type = {"Name": entity_type_name,
                               "OldName": entity_type_old_name if entity_type_old_name else None}
                self.Genealogy.append(entity_type)

            # Additional Fields
            self.Properties = {}
            additional_fields_tag = entity.getElementsByTagName("AdditionalFields")
            additional_fields = additional_fields_tag[0].getElementsByTagName("Field") if additional_fields_tag else []
            for field in additional_fields:
                name = field.getAttribute("Name")
                value = self._get_text(field)
                self.Properties[name] = value
                for entity_type in self.Genealogy:
                    v3_property_name = translate_legacy_property_name(entity_type["Name"], name)
                    if v3_property_name is not None:
                        self.Properties[v3_property_name] = value

            # Transform Settings
            self.TransformSettings = {}
            settings_tag = maltego_msg.getElementsByTagName("TransformFields")
            settings = settings_tag[0].getElementsByTagName("Field") if settings_tag else []
            for setting in settings:
                name = setting.getAttribute("Name")
                value = self._get_text(setting)
                self.TransformSettings[name] = value
        elif LocalArgs:
            self.Value = LocalArgs[0]
            self.Type = "local.Unknown"
            self.Genealogy = None

            self.Weight = 100
            self.Slider = 100

            if len(LocalArgs) > 1:
                hash_rnd = uuid.uuid4().hex.upper()[0:7]
                equals_rnd = uuid.uuid4().hex.upper()[0:7]
                bslash_rnd = uuid.uuid4().hex.upper()[0:7]
                text = LocalArgs[1] \
                    .replace("\\\\", bslash_rnd) \
                    .replace("\\#", hash_rnd) \
                    .replace("\\=", equals_rnd)

                self.buildProperties(text.split("#"), hash_rnd, equals_rnd, bslash_rnd)
                self.TransformSettings = {}

    def clearLegacyProperties(self):
        to_clear = set()
        for entity_type in self.Genealogy or []:
            for prop_name in entity_property_map.get(entity_type["Name"], []):
                to_clear.add(prop_name)

        for field_name in to_clear:
            if field_name in self.Properties:
                del self.Properties[field_name]

    def buildProperties(self, key_value_array, hash_rnd, equals_rnd, bslash_rnd):
        self.Properties = {}
        for property_section in key_value_array:
            name, value = property_section.split("=", 2)
            self.Properties[name] = value \
                .replace(hash_rnd, "#") \
                .replace(equals_rnd, "=") \
                .replace(bslash_rnd, "\\")

    def getProperty(self, key):
        return self.Properties.get(key)

    def getTransformSetting(self, key):
        return self.TransformSettings.get(key)



import os
from dataclasses import dataclass, field
from itertools import chain
from typing import List, Optional, Dict, Iterable

from maltego_trx.utils import filter_unique, pascal_case_to_title, escape_csv_fields, export_as_csv, serialize_bool, \
    name_to_path

TRANSFORMS_CSV_HEADER = "Owner,Author,Disclaimer,Description,Version," \
                        "Name,UIName,URL,entityName," \
                        "oAuthSettingId,transformSettingIDs,seedIDs"
SETTINGS_CSV_HEADER = "Name,Type,Display,DefaultValue,Optional,Popup"


@dataclass()
class TransformMeta:
    class_name: str
    display_name: str
    input_entity: str
    description: str
    output_entities: List[str]
    disclaimer: str


@dataclass()
class TransformSetting:
    name: str
    display_name: str
    setting_type: str  # Literal['string', 'boolean', 'date', 'datetime', 'daterange', 'url', 'double', 'int']

    default_value: Optional[str] = ""
    optional: bool = False
    popup: bool = False
    global_setting: bool = False

    @property
    def id(self) -> str:
        """this setting's full id for reference"""
        if self.global_setting:
            return "global#" + self.name
        return self.name


@dataclass(eq=False)
class TransformRegistry:
    owner: str
    author: str

    host_url: str
    seed_ids: List[str]

    version: str = '0.1'
    display_name_suffix: str = ""

    global_settings: List[TransformSetting] = field(default_factory=list)
    oauth_settings_id: Optional[str] = ""

    transform_metas: Dict[str, TransformMeta] = field(init=False, default_factory=dict)
    transform_settings: Dict[str, List[TransformSetting]] = field(init=False, default_factory=dict)

    def register_transform(self, display_name: str, input_entity: str, description: str,
                           settings: List[TransformSetting] = None, output_entities: List[str] = None,
                           disclaimer: str = ""):
        """ This method can be used as a decorator on transform classes. The data will be used to fill out csv config
            files to be imported into a TDS.
        """

        def decorated(transform_callable: object):
            cleaned_transform_name = name_to_path(transform_callable.__name__)
            display = display_name or pascal_case_to_title(transform_callable.__name__)

            meta = TransformMeta(cleaned_transform_name,
                                 display, input_entity,
                                 description,
                                 output_entities or [],
                                 disclaimer)
            self.transform_metas[cleaned_transform_name] = meta

            if settings:
                self.transform_settings[cleaned_transform_name] = settings

            return transform_callable

        return decorated

    def write_transforms_config(self, config_path: str = "./transforms.csv", csv_line_limit: int = 100):
        """Exports the collected transform meta data as a csv-file to config_path"""
        global_settings_full_names = [gs.id for gs in self.global_settings]

        csv_lines = []
        for transform_name, transform_meta in self.transform_metas.items():
            meta_settings = [setting.id for setting in
                             self.transform_settings.get(transform_name, [])]

            transform_row = [
                    self.owner,
                    self.author,
                    transform_meta.disclaimer,
                    transform_meta.description,
                    self.version,
                    transform_name,
                    transform_meta.display_name + self.display_name_suffix,
                    os.path.join(self.host_url, "run", transform_name),
                    transform_meta.input_entity,
                    ";".join(self.oauth_settings_id),
                    # combine global and transform scoped settings
                    ";".join(chain(meta_settings, global_settings_full_names)),
                    ";".join(self.seed_ids)
            ]

            escaped_fields = escape_csv_fields(*transform_row)
            csv_lines.append(",".join(escaped_fields))

        export_as_csv(TRANSFORMS_CSV_HEADER, csv_lines, config_path, csv_line_limit)

    def write_settings_config(self, config_path: str = "./settings.csv", csv_line_limit: int = 100):
        """Exports the collected settings meta data as a csv-file to config_path"""
        chained_settings = chain(self.global_settings, *list(self.transform_settings.values()))
        unique_settings: Iterable[TransformSetting] = filter_unique(lambda s: s.name, chained_settings)

        csv_lines = []
        for setting in unique_settings:
            setting_row = [
                    setting.id,
                    setting.setting_type,
                    setting.display_name,
                    setting.default_value or "",
                    serialize_bool(setting.optional, 'True', 'False'),
                    serialize_bool(setting.popup, 'Yes', 'No')
            ]

            escaped_fields = escape_csv_fields(*setting_row)
            csv_lines.append(",".join(escaped_fields))

        export_as_csv(SETTINGS_CSV_HEADER, csv_lines, config_path, csv_line_limit)



from maltego_trx.entities import Phrase
from maltego_trx.overlays import OverlayPosition, OverlayType

from maltego_trx.transform import DiscoverableTransform


class OverlayExample(DiscoverableTransform):
    """
    Returns a phrase with overlays on the graph.
    """

    @classmethod
    def create_entities(cls, request, response):
        person_name = request.Value
        entity = response.addEntity(Phrase, "Hi %s, nice to meet you!" % person_name)

        # Normally, when we create an overlay, we would reference a property name so that Maltego can then use the
        # value of that property to create the overlay. Sometimes that means creating a dynamic property, but usually
        # it's better to either use an existing property, or, if you created the Entity yourself, and only need the
        # property for the overlay, to use a hidden property. Here's an example of using a dynamic property:
        entity.addProperty('dynamic_overlay_icon_name', displayName="Name for overlay image", value="Champion")
        entity.addOverlay('dynamic_overlay_icon_name', OverlayPosition.WEST, OverlayType.IMAGE)

        # You *can* also directly supply the string value of the property, however this is not recommended. Why? If
        # the entity already has a property of the same ID (in this case, "DE"), then you would in fact be assigning the
        # value of that property, not the string "DE", which is not the intention. Nevertheless, here's an example:
        entity.addOverlay('DE', OverlayPosition.SOUTH_WEST, OverlayType.IMAGE)

        # Overlays can also be an additional field of text displayed on the entity:
        entity.addProperty("exampleDynamicPropertyName", "Example Dynamic Property", "loose", "Maltego Overlay Testing")
        entity.addOverlay('exampleDynamicPropertyName', OverlayPosition.NORTH, OverlayType.TEXT)

        # Or a small color indicator
        entity.addOverlay('#45e06f', OverlayPosition.NORTH_WEST, OverlayType.COLOUR)




from setuptools import setup
from maltego_trx import VERSION

setup(
    name='maltego-trx',
    version=VERSION,
    description='Python library used to develop Maltego transforms',
    url='https://github.com/paterva/maltego-trx/',
    author='Maltego Staff',
    author_email='support@maltego.com',
    license='MIT',
    install_requires=[
        'flask>=1',
        'six>=1',
        'cryptography==3.3.2'  # pinned for now as newer versions require setuptools_rust
    ],
    extras_require={
        ':python_version == "3.6"': [
            'dataclasses',
        ],
    },
    packages=[
        'maltego_trx',
        'maltego_trx/template_dir',
        'maltego_trx/template_dir/transforms'
    ],
    entry_points={
        'console_scripts': [
            'maltego-trx = maltego_trx.commands:execute_from_command_line',
        ]
    },
    zip_safe=False
)
